@@ -3,7 +3,7 @@ REST Handler for WSGI application
 """
 
 __author__ = 'VMware, Inc.'
-__copyright__ = 'Copyright 2015-2020 VMware, Inc.  All rights reserved. -- VMware Confidential'  # pylint: disable=line-too-long
+__copyright__ = 'Copyright 2015-2020, 2023 VMware, Inc.  All rights reserved. -- VMware Confidential'  # pylint: disable=line-too-long
 
 import base64
 import collections
@@ -149,12 +149,13 @@ class MetadataStore(object):
         components = component_svc.list()
         for component_id in components:
             component_data = component_svc.get(component_id)
-            self._process_component_info(component_data.info)
+            self._create_structure_map(component_data.info)
+            self._create_operation_map(component_data.info)
 
-    def _process_component_info(self, component_info):
+    def _create_structure_map(self, component_info):
         """
         Process the metamodel component information. Scan the packages
-        for services, structures and enumerations and store into dictionaries
+        and services for structures and enumerations and store into dictionaries
         for fast lookup.
 
         :type  component_info:
@@ -171,11 +172,25 @@ class MetadataStore(object):
             for service_id, service_info in six.iteritems(
                                             package_info.services):
                 self._process_service_info(service_id, service_info)
+
+
+    def _create_operation_map(self, component_info):
+        """
+        Process the metamodel component information. Scan services for
+        operations and store into dictionaries for fast lookup.
+
+        :type  component_info:
+               :class:`com.vmware.vapi.metadata.metamodel_client.ComponentInfo`
+        :param component_info: Metamodel component information to be processed
+        """
+        for package_info in six.itervalues(component_info.packages):
+            for service_id , service_info in six.iteritems(package_info.services):
                 self.service_map[service_id] = {
                     operation_id: self._create_operation_summary(operation_info,
                                                                  service_id)
                         for operation_id, operation_info in six.iteritems(
-                                                    service_info.operations)}
+                                                    service_info.operations)
+                }
 
     def _get_header_and_query_variables(self, param_info_map):
         """
@@ -755,6 +770,10 @@ class DataValueDeserializer(object):
                     msg = 'Unexpected field \'%s\' in request' % field_name
                     logger.error(msg)
                     raise werkzeug.exceptions.BadRequest(msg)
+                except CoreException as e:
+                    msg = 'Unable to parse property with name \'%s\': %s' % (field_name, e)
+                    logger.exception(msg)
+                    raise werkzeug.exceptions.BadRequest(msg)
             return struct_value
         else:
             msg = ('Could not process the request,'
