@@ -535,30 +535,6 @@ class CustomRequestMappingRule(MappingRule):
         """
         return bool(operation_summary.has_request_mapping_metadata())
 
-    #TODO: Delete this method once idl-toolkit does these validations
-    @staticmethod
-    def _validate_action_param(param, http_method):
-        """
-        Validate the fixed query parameter in value element of RequestMapping.
-        """
-        if not http_method == 'POST':
-            raise Exception(
-                "Fixed query param 'action' is supported only for HTTP "
-                "POST method")
-        if not param.startswith(RestAnnotations.ACTION_PARAM) or \
-                len(param.split('&')) > 1:
-            raise Exception((
-                "Illegal fixed param '%s'. "
-                "Only one fixed param is supported - '?%s=<op>'.") %
-                (param, RestAnnotations.ACTION_PARAM))
-        if len(param.split('=')) != 2:
-            raise Exception(
-                "Illegal value '%s' for fixed param." % param)
-        (_, action_value) = param.split('=')
-        if not action_value:
-            raise Exception(
-                "Illegal value '%s' for fixed param." % param)
-
     def url(self, service_id, operation_id, operation_summary):
         """
         Generate the mapping rule for an operation that has RequestMapping
@@ -588,7 +564,6 @@ class CustomRequestMappingRule(MappingRule):
         if '?' in custom_url:
             (custom_url, param) = custom_url.split('?')
             (_, action_value) = param.split('=')
-            self._validate_action_param(param, http_method)
         else:
             params = request_mapping.elements.get(
                 RestAnnotations.PARAMS_ELEMENT)
@@ -599,7 +574,6 @@ class CustomRequestMappingRule(MappingRule):
                     if (len(param_split) == 2
                             and param_split[0] == RestAnnotations.ACTION_PARAM):
                         action_value = param_split[1]
-                        self._validate_action_param(param, http_method)
                         break
 
             else:
@@ -955,6 +929,9 @@ class RoutingRuleGenerator(object):
             and query params
         """
         for mapping_rule in self._mapping_rules:
+            if service_id == 'com.vmware.cis.session' and type(mapping_rule) == VerbMappingRule:
+                continue
+
             if mapping_rule.match(operation_id, operation_summary):
                 return mapping_rule.url(service_id, operation_id,
                                         operation_summary)
